#!/bin/bash
 
# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# last revised : 24/04/2010
#
#package			: guayadeque
#homepage			: http://sourceforge.net/projects/guayadeque
#source location	: http://iweb.dl.sourceforge.net/project/guayadeque/guayadeque/0.2.5/guayadeque-0.2.5.tar.gz
#dependency         : 
set -e -u -x
#> log
(

softname='guayadeque'
softversion='0.2.5'
zenver='64.1'
arch='i486'
cpu='i686'
numjobs='-j2'

#>

buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$zenver"
dest="$buildir/$package"
source=(http://iweb.dl.sourceforge.net/project/guayadeque/guayadeque/0.2.5/guayadeque-0.2.5.tar.gz)
sourcetemplate=http://zenwalk.pinguix.com/user-accounts/stillborn/guayadeque

#>

rm -rf $dest
mkdir -p $dest/{install,usr/{doc/$softname-$softversion,share/{applications,icons/hicolor/{48x48,64x64}/apps},src/$softname-$softversion}}

#> prepare slack-desc
cat <<EOF > $dest/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
guayadeque: guayadeque - Music Player with the aims to be intuitive, easy to use
guayadeque:
guayadeque: and fast even for huge music collections. Developed for Linux with
guayadeque: wxWidgets for GTK under Gnome.
guayadeque: 
guayadeque: 
guayadeque: 
guayadeque:
guayadeque:
guayadeque:
guayadeque:
EOF

#> check for sources
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar xzvf $srcpkg

cd $src	
./build
make
make install DESTDIR=$dest

#> prepare icon
cp -v $dest/usr/share/pixmaps/$softname.png $dest/usr/share/icons/hicolor/48x48/apps
convert $dest/usr/share/icons/hicolor/48x48/apps/$softname.png -resize 48x48 $softname.png
mv -v $dest/usr/share/app-install/icons/$softname.png $dest/usr/share/icons/hicolor/64x64/apps
rm -rfv $dest/usr/share/app-install

#> add docs, infos, ...
(cd $src
cp -av \
      LICENSE README changelog \
$dest/usr/doc/$softname-$softversion
)

#> Strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

#> store buildscript 
(
cd $buildir
cp -v build-$softname.sh $dest/usr/src/$softname-$softversion
)

#> fix permissions
(
chown -R root:root $dest
cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(
cd $dest
makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
depfinder $package.txz > $package.dep

#>

rm -rf $src
rm -rf $dest


#> log
) 2>&1 | tee guayadeque-build.log.txt
